@@ -264,10 +264,14 @@ class Application(QApplication, Singleton):
         confo.ghosting = ConfDB().value("Dynamips/dynamips_ghosting", QVariant(True)).toBool()
         confo.mmap = ConfDB().value("Dynamips/dynamips_mmap", QVariant(True)).toBool()
         confo.sparsemem = ConfDB().value("Dynamips/dynamips_sparsemem", QVariant(False)).toBool()
-        confo.memory_limit =int(ConfDB().get("Dynamips/hypervisor_memory_usage_limit", 512))
+        confo.jitsharing = ConfDB().value("Dynamips/dynamips_jitsharing", QVariant(True)).toBool()
+        if sys.platform.startswith('win'):
+            confo.memory_limit = int(ConfDB().get("Dynamips/hypervisor_memory_usage_limit", 512))
+        else:
+            confo.memory_limit = int(ConfDB().get("Dynamips/hypervisor_memory_usage_limit", 1024))
         confo.udp_incrementation = int(ConfDB().get("Dynamips/hypervisor_udp_incrementation", 100))
         confo.import_use_HypervisorManager = ConfDB().value("Dynamips/hypervisor_manager_import", QVariant(True)).toBool()
-        confo.HypervisorManager_binding = ConfDB().get('Dynamips/hypervisor_manager_binding', unicode('localhost'))
+        confo.HypervisorManager_binding = ConfDB().get('Dynamips/hypervisor_manager_binding', unicode('127.0.0.1'))
 
         # replace ~user and $HOME by home directory
         if os.environ.has_key("HOME"):
@@ -286,7 +290,7 @@ class Application(QApplication, Singleton):
         confo.external_hosts = ConfDB().get('Qemu/external_hosts', unicode('localhost:10525')).split(',')
         confo.enable_QemuManager = ConfDB().value("Qemu/enable_QemuManager", QVariant(True)).toBool()
         confo.import_use_QemuManager = ConfDB().value("Qemu/qemu_manager_import", QVariant(True)).toBool()
-        confo.QemuManager_binding = ConfDB().get('Qemu/qemu_manager_binding', unicode('localhost'))
+        confo.QemuManager_binding = ConfDB().get('Qemu/qemu_manager_binding', unicode('127.0.0.1'))
         confo.qemuwrapper_port = int(ConfDB().get('Qemu/qemuwrapper_port', 10525))
         confo.qemuwrapper_baseUDP = int(ConfDB().get('Qemu/qemuwrapper_baseUDP', 20000))
         confo.qemuwrapper_baseConsole = int(ConfDB().get('Qemu/qemuwrapper_baseConsole', 3000))
@@ -478,6 +482,7 @@ class Application(QApplication, Singleton):
         c.set('Dynamips/clean_working_directory', confo.clean_workdir)
         c.set('Dynamips/dynamips_ghosting', confo.ghosting)
         c.set('Dynamips/dynamips_sparsemem', confo.sparsemem)
+        c.set('Dynamips/dynamips_jitsharing', confo.jitsharing)
         c.set('Dynamips/dynamips_mmap', confo.mmap)
         c.set('Dynamips/hypervisor_memory_usage_limit', confo.memory_limit)
         c.set('Dynamips/hypervisor_udp_incrementation', confo.udp_incrementation)
