@@ -119,6 +119,48 @@ class NETFile(object):
                     self.add_in_connection_list((device.name, 'e' + str(port), remote_device.name, remote_adapter + str(remote_port)), connection_list)
                 elif isinstance(remote_device, lib.ETHSW):
                     connection_list.append((device.name, 'e' + str(port), remote_device.name, str(remote_port)))
+                    
+    def populate_connection_list_for_emulated_switch(self, device, connection_list):
+        """ Add emulated switch connections in connection_list
+        """
+
+        if isinstance(device, lib.ETHSW):
+            keys = device.mapping.keys()
+            for port in keys:
+                nio_port = device.nio(port)
+                # Only NIO_udp
+                if nio_port and isinstance(nio_port, lib.NIO_udp):
+                    (remote_device, remote_adapter, remote_port) = lib.get_reverse_udp_nio(nio_port)
+                    if isinstance(remote_device, lib.ETHSW):
+                        self.add_in_connection_list((device.name, str(port), remote_device.name, str(remote_port)), connection_list)
+        
+        if isinstance(device, lib.FRSW):
+            keys = device.pvcs.keys()
+            for (port, dlci) in keys:
+                nio_port = device.nio(port)
+                if nio_port:
+                    (remote_device, remote_adapter, remote_port) = lib.get_reverse_udp_nio(nio_port)
+                    if isinstance(remote_device, lib.FRSW):
+                        self.add_in_connection_list((device.name, str(port), remote_device.name, str(remote_port)), connection_list)
+
+        if isinstance(device, lib.ATMSW):
+            keys = device.vpivci_map.keys()
+            for key in keys:
+                port = key[0]
+                nio_port = device.nio(port)
+                if nio_port:
+                    (remote_device, remote_adapter, remote_port) = lib.get_reverse_udp_nio(nio_port)
+                    if isinstance(remote_device, lib.ATMSW) or isinstance(remote_device, lib.ATMBR):
+                        self.add_in_connection_list((device.name, str(port), remote_device.name, str(remote_port)), connection_list)
+                        
+        if isinstance(device, lib.ATMBR):
+            keys = device.mapping.keys()
+            for port in keys:
+                nio_port = device.nio(port)
+                if nio_port:
+                    (remote_device, remote_adapter, remote_port) = lib.get_reverse_udp_nio(nio_port)
+                    if isinstance(remote_device, lib.ATMSW) or isinstance(remote_device, lib.ATMBR):
+                        self.add_in_connection_list((device.name, str(port), remote_device.name, str(remote_port)), connection_list)       
 
     def create_node(self, device, default_symbol_name, running_config_name):
         """ Create a new node
@@ -128,8 +170,11 @@ class NETFile(object):
         config = None
         if isinstance(device, qlib.AnyEmuDevice) and self.dynagen.globalconfig['qemu ' + device.dynamips.host +':' + str(device.dynamips.port)].has_key(running_config_name):
             config = self.dynagen.globalconfig['qemu ' + device.dynamips.host +':' + str(device.dynamips.port)][running_config_name]
-        elif self.dynagen.globalconfig[device.dynamips.host +':' + str(device.dynamips.port)].has_key(running_config_name):
+        elif self.dynagen.globalconfig.has_key(device.dynamips.host +':' + str(device.dynamips.port)) and \
+            self.dynagen.globalconfig[device.dynamips.host +':' + str(device.dynamips.port)].has_key(running_config_name):
             config = self.dynagen.globalconfig[device.dynamips.host +':' + str(device.dynamips.port)][running_config_name]
+        elif self.dynagen.globalconfig.has_key(device.dynamips.host) and self.dynagen.globalconfig[device.dynamips.host].has_key(running_config_name):
+            config = self.dynagen.globalconfig[device.dynamips.host][running_config_name]
 
         if config:
             if config.has_key('x'):
@@ -405,6 +450,13 @@ class NETFile(object):
                     
                 if devtype.lower() == 'pixmap':
                     pixmap_path = unicode(gns3data[section]['path'])
+                    
+                    # Check if this is a relative pixmap path and convert to an absolute path if necessary
+                    abspath = os.path.join(os.path.dirname(self.dynagen.filename), pixmap_path)
+                    if os.path.exists(abspath):
+                        pixmap_path = abspath
+                        debug(unicode("Converting relative pixmap path to absolute path: %s") % pixmap_path)
+
                     pixmap_image = QtGui.QPixmap(pixmap_path)
                     if not pixmap_image.isNull():
                         pixmap_object= Pixmap(pixmap_image, pixmap_path)
@@ -446,7 +498,8 @@ class NETFile(object):
                         config = decorative_node.get_config()
                         for connection in connections:
                             (device, remote_interface, local_interface) = connection.split(':', 2)
-                            self.decorative_node_connections[(device, remote_interface, local_interface)] = decorative_node.id
+                            if not self.decorative_node_connections.has_key((hostname, local_interface, remote_interface)):
+                                self.decorative_node_connections[(device, remote_interface, local_interface)] = decorative_node.id
                             if local_interface not in config['interfaces']:
                                 config['interfaces'].append(local_interface)
 
@@ -486,6 +539,7 @@ class NETFile(object):
             splash = QtGui.QSplashScreen(QtGui.QPixmap(":images/logo_gns3_splash.png"))
             splash.show()
             splash.showMessage(translate("NETFile", "Please wait while importing the topology"))
+            globals.GApp.processEvents(QtCore.QEventLoop.AllEvents | QtCore.QEventLoop.WaitForMoreEvents, 1000)
             self.dynagen.ghosting()
             self.dynagen.jitsharing()
         except lib.DynamipsError, msg:
@@ -558,7 +612,7 @@ class NETFile(object):
                 keys = device.mapping.keys()
                 keys.sort()
                 for port in keys:
-                    (porttype, vlan, nio, twosided)= device.mapping[port]
+                    (porttype, vlan, nio, twosided) = device.mapping[port]
                     if not config['vlans'].has_key(vlan):
                         config['vlans'][vlan] = []
                     if twosided:
@@ -572,6 +626,7 @@ class NETFile(object):
                         cloud.startNode()
                 node.set_config(config)
                 node.set_hypervisor(device.dynamips)
+                self.populate_connection_list_for_emulated_switch(device, connection_list)
                 match_obj = ethsw_hostname_re.match(node.hostname)
                 if match_obj:
                     id = int(match_obj.group(1))
@@ -585,7 +640,7 @@ class NETFile(object):
                 config['mapping'] = {}
                 keys = device.pvcs.keys()
                 keys.sort()
-                for (port1,dlci1) in keys:
+                for (port1, dlci1) in keys:
                     (port2, dlci2) = device.pvcs[(port1, dlci1)]
                     if not port1 in config['ports']:
                         config['ports'].append(port1)
@@ -597,6 +652,7 @@ class NETFile(object):
                 self.configure_node(node, device)
                 node.set_config(config)
                 node.set_hypervisor(device.dynamips)
+                self.populate_connection_list_for_emulated_switch(device, connection_list)
                 match_obj = frsw_hostname_re.match(node.hostname)
                 if match_obj:
                     id = int(match_obj.group(1))
@@ -634,6 +690,7 @@ class NETFile(object):
                 self.configure_node(node, device)
                 node.set_config(config)
                 node.set_hypervisor(device.dynamips)
+                self.populate_connection_list_for_emulated_switch(device, connection_list)
                 match_obj = atmsw_hostname_re.match(node.hostname)
                 if match_obj:
                     id = int(match_obj.group(1))
@@ -658,6 +715,7 @@ class NETFile(object):
                 self.configure_node(node, device)
                 node.set_config(config)
                 node.set_hypervisor(device.dynamips)
+                self.populate_connection_list_for_emulated_switch(device, connection_list)
                 match_obj = atmsw_hostname_re.match(node.hostname)
                 if match_obj:
                     id = int(match_obj.group(1))
@@ -735,6 +793,9 @@ class NETFile(object):
         globals.GApp.workspace.projectFile = path
         globals.GApp.workspace.setWindowTitle("GNS3 - " + globals.GApp.workspace.projectFile)
         debug("Running config after importing: " + str(self.dynagen.running_config))
+        
+        for node in globals.GApp.topology.nodes.itervalues():
+            node.updateToolTips()
 
     def export_router_config(self, device):
 
@@ -743,12 +804,12 @@ class NETFile(object):
             config = config.replace('\r', "")
             # Write out the config to a file
             file_path = os.path.normpath(globals.GApp.workspace.projectConfigs) + os.sep + device.name + '.cfg'
-            debug(unicode(translate("NETFile", "Exporting %s configuration to %s")) % (device.name, file_path))
+            print unicode(translate("NETFile", "Exporting %s configuration to %s")) % (device.name, file_path)
         except lib.DynamipsError, msg:
-            debug(unicode(device.name + ': ' + translate("NETFile", "Dynamips error") + ': ') + unicode(msg))
+            print unicode(device.name + ': ' + translate("NETFile", "Dynamips error") + ': ') + unicode(msg)
             return
         except lib.DynamipsWarning, msg:
-            debug(unicode(device.name + ': ' + translate("NETFile", "Dynamips warning") + ': ') + unicode(msg))
+            print unicode(device.name + ': ' + translate("NETFile", "Dynamips warning") + ': ') + unicode(msg)
             return
         except:
             error('Unknown error exporting config for ' + device.name)
@@ -887,8 +948,11 @@ class NETFile(object):
                 if not self.dynagen.running_config.has_key('GNS3-DATA'):
                     self.dynagen.running_config['GNS3-DATA'] = {}
                 self.dynagen.running_config['GNS3-DATA']['PIXMAP ' + str(pix_nb)] = {}
-                config = self.dynagen.running_config['GNS3-DATA']['PIXMAP ' + str(pix_nb)] 
-                config['path'] = item.pixmap_path
+                config = self.dynagen.running_config['GNS3-DATA']['PIXMAP ' + str(pix_nb)]
+                if globals.GApp.systconf['general'].relative_paths:
+                    config['path'] = self.convert_to_relpath(item.pixmap_path, path)
+                else:
+                    config['path'] = item.pixmap_path
                 config['x'] = item.x()
                 config['y'] = item.y()
                 zvalue = item.zValue()
@@ -1004,7 +1068,11 @@ class NETFile(object):
                         device['cnfg'] = self.convert_to_relpath(device['cnfg'], path)
         
         self.dynagen.running_config.filename = path
-        self.dynagen.running_config.write()
+        try:
+            self.dynagen.running_config.write()  
+        except IOError, e:
+            QtGui.QMessageBox.critical(globals.GApp.mainWindow, 
+                                      unicode(device.name) + ': ' + translate("NETFile", "IOError"), unicode(translate("NETFile", "%s: IO Error: %s")) % (path, unicode(e)))        
         self.dynagen.running_config.filename = None
         
     def convert_to_relpath(self, path, config_path):
