@@ -12,6 +12,7 @@ FILES=" Form_MainWindow
 	Form_Wizard
 	Form_StyleDialog
 	Form_StartupConfig
+	Form_MACTableDialog
         ./ConfigurationPages/Form_IOSRouterPage
         ./ConfigurationPages/Form_CloudPage
         ./ConfigurationPages/Form_ETHSWPage
@@ -34,5 +35,5 @@ FILES=" Form_MainWindow
 for file in $FILES;
 do
     echo "Generating $file"
-    /opt/local/var/macports/software/py26-pyqt4/4.6.2_0/opt/local/bin/pyuic4-2.6 "$file.ui" > "$file.py"
+    /opt/local/Library/Frameworks/Python.framework/Versions/2.6/bin/pyuic4 "$file.ui" > "$file.py"
 done
