@@ -92,6 +92,10 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.menu_Edit.insertAction(self.action_SelectAll, action)
 
         self.menu_Edit.insertAction(self.action_SelectAll, self.menu_Edit.addSeparator())
+        
+        # Class to display error/warning messages once
+        self.errorMessage = QtGui.QErrorMessage(self)
+        self.errorMessage.setMinimumSize(350, 200)
 
     def __connectActions(self):
         """ Connect all needed pair (action, SIGNAL)
@@ -204,8 +208,8 @@ class Workspace(QMainWindow, Ui_MainWindow):
                         min_y = item.y()
                 x = min_x - 30
                 y = min_y - 30
-                width = abs(x) + max_x + 90
-                height = abs(y) + max_y + 80
+                width = abs(x) + max_x + 200
+                height = abs(y) + max_y + 200
     
             else:
 
@@ -280,7 +284,6 @@ class Workspace(QMainWindow, Ui_MainWindow):
                 # delete useless project files
                 dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "*ghost*")
                 dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "c[0-9][0-9][0-9][0-9]_*_log.txt")
-                dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "c[0-9][0-9][0-9][0-9]_*_bootflash")
                 dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "c[0-9][0-9][0-9][0-9]_*_rommon_vars")
                 dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "c[0-9][0-9][0-9][0-9]_*_ssa")
 
@@ -908,8 +911,9 @@ class Workspace(QMainWindow, Ui_MainWindow):
             return
 
         (path, selected) = fileBrowser(translate("Workspace", "Open a file"),  filter = 'NET file (*.net);;All files (*.*)',
-                                       directory=globals.GApp.systconf['general'].project_path, parent=self).getFile()
-        if path != None and (selected == 'NET file (*.net)' or selected == ''):
+                                       directory=os.path.normpath(globals.GApp.systconf['general'].project_path), parent=self).getFile()
+
+        if path and (selected == 'NET file (*.net)' or selected == ''):
             self.loadNetfile(path)
                 
     def loadNetfile(self, path):
@@ -942,9 +946,8 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """ Save as (scenario or dynagen .NET format)
         """
 
-        fb = fileBrowser(translate("Workspace", "Save Project As"),
-                                filter='NET file (*.net);;All files (*.*)', directory=os.path.normpath(globals.GApp.systconf['general'].project_path), parent=self)
-        (path, selected) = fb.getSaveFile()
+        (path, selected) = fileBrowser(translate("Workspace", "Save Project As"),
+                                filter='NET file (*.net);;All files (*.*)', directory=os.path.normpath(globals.GApp.systconf['general'].project_path), parent=self).getSaveFile()
 
         if path != None and path != '':
             if str(selected) == 'NET file (*.net)' or selected == '':
